# Implements KeyPressMonitor and TypingTracker classes for easily checking for keypresses and typed text

import mbase

class KeyPressMonitor:
    def __init__(self):
        self.comboList = []
        
    def registerCombination(self, combination, onpress, onrelease, argument):
        self.comboList.append([combination, onpress, onrelease, argument, False])
    
    def processKeys(self):
        for item in self.comboList:
            curState = (sum(mbase.checkKeysPressed(list(item[0]))) == len(item[0]))
            
            if curState and not item[4]:
                if item[1]: item[1](item[3])
            elif item[4] and not curState:
                if item[2]: item[2](item[3])
                
            item[4] = curState

class TypingTracker:
    def __init__(self, changeNotifier):
        self.charList = []
        self.keyList = []
        self.oldState = []
        self.typeString = ""
        self.typeActive = False
        self.changeNotifier = changeNotifier
        
        for charKey in range(ord('A'), ord('Z')+1):
            self.addKey(charKey, chr(charKey))
            
        for charKey in range(ord('0'), ord('9')+1):
            self.addKey(charKey, chr(charKey))
            
        self.addKey(32, " ")
        
    def addKey(self, keyCode, character):
        self.keyList.append(keyCode)
        self.charList.append(character)
        self.oldState.append(False)
        
    def beginTyping(self):
        self.typeString = ""
        self.typeActive = True
        
    def endTyping(self):
        self.typeActive = False
        
        finalString = self.typeString
        self.typeString = ""
        
        return finalString
        
    def processKeys(self):
        newState = mbase.checkKeysPressed(list(self.keyList))
        
        for i in range(len(self.charList)):
            if newState[i] and not self.oldState[i]:
                self.typeString += self.charList[i]
                
                if self.changeNotifier:
                    self.changeNotifier(self.typeString)
                
        self.oldState = newState
